@@ -21,7 +21,9 @@
 #include <machine/xen.h>
 #include <string.h>
 
+#include <mach/port.h>
 #include <device/cons.h>
+#include <device/io_req.h>
 
 #define hyp_console_write(str, len)	hyp_console_io (CONSOLEIO_write, (len), kvtolin(str))
 
@@ -37,4 +39,12 @@ extern int hypcngetc(dev_t dev, int wait);
 extern int hypcnprobe(struct consdev *cp);
 extern int hypcninit(struct consdev *cp);
 
+extern int hypcnopen(dev_t dev, int flag, io_req_t ior);
+extern int hypcnread(int dev, io_req_t ior);
+extern int hypcnwrite(int dev, io_req_t ior);
+extern int hypcnclose(int dev, int flag);
+extern io_return_t hypcngetstat(dev_t dev, int flavor, int *data, unsigned int *count);
+extern io_return_t hypcnsetstat(dev_t dev, int flavor, int *data, unsigned int count);
+extern int hypcnportdeath(dev_t dev, mach_port_t port);
+
 #endif /* XEN_CONSOLE_H */
